# ideally, we would only require a client if it's in use
Dir[File.expand_path(File.dirname(__FILE__) + '/clients/*.rb')].each { |file| require file }

class StoolieFilterClientException < Exception; end

module Stoolie
  class Filter
    attr_accessor :client, :result

    # Public: takes the class name of the filter client to use - e.g. SmartFilter
    def initialize(client = nil)
      raise StoolieFilterClientException.new("client must be a Class") if client and !client.is_a?(Class)

      @config = Stoolie.configure

      @client = client || Stoolie.config.client
      @client = @client.send(:new)
    end

    # Public: analyzes a string for xss, spam and profanity
    #
    # input - the string to be analyzed
    #
    # Examples:
    #
    #   analyze('<script>text</script>')
    #   # => #<Stoolie::Result: ...>
    #
    # Returns a Stoolie::Result object
    def analyze(input)
      @result = @client.analyze(input)
    end
  end
end
